==> spoqa-han-sans-3.0.0.tgz: package/README.md <==
Spoqa Han Sans Neo v3.0.0
=========================

[![npm version](https://badge.fury.io/js/spoqa-han-sans.svg)](https://www.npmjs.com/package/spoqa-han-sans)
[![Build Status](https://travis-ci.org/spoqa/spoqa-han-sans.svg?branch=master)](https://travis-ci.org/spoqa/spoqa-han-sans)
[![GitHub release](https://img.shields.io/github/release/spoqa/spoqa-han-sans.svg)](https://github.com/spoqa/spoqa-han-sans)


스포카 한 산스는 국문, 영문, 일문, 숫자, 글리프의 어울림이 훌륭합니다.
가는 굵기(Thin), 보통 굵기(Regular), 중간 굵기 (Medium), 두꺼운 굵기(Bold) 네 가지 자족으로,
디지털 환경에서 언어를 아름답게 표현합니다.

스포카 혼자 쓰기엔 지나치게 산뜻한 스포카 한 산스 네오,
누구나 무료로 쓸 수 있도록 배포합니다.


## 폰트 다운로드

- [All](https://github.com/spoqa/spoqa-han-sans/releases/download/v3.0.0/SpoqaHanSansNeo_all.zip)
- [TTF Original](https://github.com/spoqa/spoqa-han-sans/releases/download/v3.0.0/SpoqaHanSansNeo_TTF_original.zip)
- [OTF Original](https://github.com/spoqa/spoqa-han-sans/releases/download/v3.0.0/SpoqaHanSansNeo_OTF_original.zip)
- [TTF Subset](https://github.com/spoqa/spoqa-han-sans/releases/download/v3.0.0/SpoqaHanSans_TTF_subset.zip)
- [OTF Subset](https://github.com/spoqa/spoqa-han-sans/releases/download/v3.0.0/SpoqaHanSans_OTF_subset.zip)
- [JP Original](https://github.com/spoqa/spoqa-han-sans/releases/download/v2.1.2/SpoqaHanSans_JP_original.zip)
- [JP Subset](https://github.com/spoqa/spoqa-han-sans/releases/download/v2.1.2/SpoqaHanSans_JP_subset.zip)


## 폰트 설치 방법

- [OS X](https://support.apple.com/ko-kr/HT201749)
- [Windows](http://windows.microsoft.com/en-us/windows-vista/install-or-uninstall-fonts)


## 웹폰트 적용 방법

Spoqa Han Sans를 웹폰트로 사용하시려면 2가지 방법이 있습니다.

스타일 시트에 아래의 코드를 넣거나,

```css
@import url(//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSans-kr.css);
@import url(//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSans-jp.css);
```

혹은 HTML의 `<head>` 태그 안에 아래의 코드를 넣어주세요.

```html
<link href='//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSans-kr.css' rel='stylesheet' type='text/css'>
<link href='//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSans-jp.css' rel='stylesheet' type='text/css'>
```

그후 `<style>` 태그 안에  `font-family` 를 설정해주세요.

```css
* {
  font-family: 'Spoqa Han Sans', 'Spoqa Han Sans Neo', 'Spoqa Han Sans JP', sans-serif;
}
```


## 의견 보내기

Spoqa Han Sans 프로젝트에 제안하고 싶은 사항이 있다면 이슈를 생성해주시길 바랍니다.


## 제작 정보

Spoqa Han Sans에 대한 제작 배경 및 미리보기에 대한 정보는 [Spoqa Han Sans Introduction](https://spoqa.github.io/spoqa-han-sans/)에서 얻으실 수 있습니다.

## 오픈 소스

Spoqa Han Sans는 Spoqa에서 관리하고 있는 오픈 소스 서체로, [SIL Open Font License](http://scripts.sil.org/OFL)로 배포되고 있습니다.

따라서 개인 및 기업 사용자가 자유롭게 사용, 수정 및 재배포 가능하며, 저작권에 문제없이 로고, BI, CI, 임베드 등의 상업적 사용이 가능하며 자유로운 사용에 추가 비용을 지불 하실 필요도 없습니다.

([프로젝트에 기여한 분들의 목록](https://github.com/spoqa/spoqa-han-sans/graphs/contributors) 참고.)

==> spoqa-han-sans-3.3.0.tgz: package/README.md <==
Spoqa Han Sans Neo
=========================

[![npm version](https://badge.fury.io/js/spoqa-han-sans.svg)](https://www.npmjs.com/package/spoqa-han-sans)
[![Build Status](https://travis-ci.org/spoqa/spoqa-han-sans.svg?branch=master)](https://travis-ci.org/spoqa/spoqa-han-sans)
[![GitHub release](https://img.shields.io/github/release/spoqa/spoqa-han-sans.svg)](https://github.com/spoqa/spoqa-han-sans)


스포카 한 산스는 국문, 영문, 일문, 숫자, 글리프의 어울림이 훌륭합니다.
가는 굵기(Thin), 보통 굵기(Regular), 중간 굵기 (Medium), 두꺼운 굵기(Bold) 네 가지 자족으로,
디지털 환경에서 언어를 아름답게 표현합니다.

스포카 혼자 쓰기엔 지나치게 산뜻한 스포카 한 산스 네오,
누구나 무료로 쓸 수 있도록 배포합니다.


## 폰트 다운로드

- [All](https://github.com/spoqa/spoqa-han-sans/releases/latest/download/SpoqaHanSansNeo_all.zip)
- [TTF Original](https://github.com/spoqa/spoqa-han-sans/releases/latest/download/SpoqaHanSansNeo_TTF_original.zip)
- [OTF Original](https://github.com/spoqa/spoqa-han-sans/releases/latest/download/SpoqaHanSansNeo_OTF_original.zip)
- [TTF Subset](https://github.com/spoqa/spoqa-han-sans/releases/latest/download/SpoqaHanSansNeo_TTF_subset.zip)
- [OTF Subset](https://github.com/spoqa/spoqa-han-sans/releases/latest/download/SpoqaHanSansNeo_OTF_subset.zip)
- [JP Original](https://github.com/spoqa/spoqa-han-sans/releases/download/v2.1.2/SpoqaHanSans_JP_original.zip)
- [JP Subset](https://github.com/spoqa/spoqa-han-sans/releases/download/v2.1.2/SpoqaHanSans_JP_subset.zip)


## 폰트 설치 방법

- [OS X](https://support.apple.com/ko-kr/HT201749)
- [Windows](http://windows.microsoft.com/en-us/windows-vista/install-or-uninstall-fonts)


## 웹폰트 적용 방법

Spoqa Han Sans를 웹폰트로 사용하시려면 2가지 방법이 있습니다.

스타일 시트에 아래의 코드를 넣거나,

```css
@import url(//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSansNeo.css);
@import url(//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSans-jp.css);
```

혹은 HTML의 `<head>` 태그 안에 아래의 코드를 넣어주세요.

```html
<link href='//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSansNeo.css' rel='stylesheet' type='text/css'>
<link href='//spoqa.github.io/spoqa-han-sans/css/SpoqaHanSans-jp.css' rel='stylesheet' type='text/css'>
```

그후 `<style>` 태그 안에  `font-family` 를 설정해주세요.

```css
* {
  font-family: 'Spoqa Han Sans Neo', 'Spoqa Han Sans JP', sans-serif;
}
```


## 의견 보내기

Spoqa Han Sans 프로젝트에 제안하고 싶은 사항이 있다면 이슈를 생성해주시길 바랍니다.


## 제작 정보

Spoqa Han Sans에 대한 제작 배경 및 미리보기에 대한 정보는 [Spoqa Han Sans Introduction](https://spoqa.github.io/spoqa-han-sans/)에서 얻으실 수 있습니다.

## 오픈 소스

Spoqa Han Sans는 Spoqa에서 관리하고 있는 오픈 소스 서체로, [SIL Open Font License](http://scripts.sil.org/OFL)로 배포되고 있습니다.

따라서 개인 및 기업 사용자가 자유롭게 사용, 수정 및 재배포 가능하며, 저작권에 문제없이 로고, BI, CI, 임베드 등의 상업적 사용이 가능하며 자유로운 사용에 추가 비용을 지불 하실 필요도 없습니다.

([프로젝트에 기여한 분들의 목록](https://github.com/spoqa/spoqa-han-sans/graphs/contributors) 참고.)
